<?php declare(strict_types=1);

use Lewisdale\App\Controllers\FeedController;
use Lewisdale\App\Controllers\HomeController;
use Lewisdale\App\Controllers\LoginController;
use Slim\Views\TwigMiddleware;

ini_set('user_agent', 'Baleen/1.0 (https://baleen.lewisdale.dev)');
ini_set('session.name', 'sessid');
ini_set('session.cookie_samesite', 'Lax');

require_once __DIR__ . "/dependencies.php";

global $container;
global $app;

$dotenv = Dotenv\Dotenv::createImmutable([__DIR__, __DIR__ . "/.."]);
$dotenv->safeLoad();

require_once __DIR__ . "/session.php";

$app->add(TwigMiddleware::createFromContainer($app));
$app->add('csrf');

$app->get("/", [HomeController::class, 'get']);

$app->get('/feed', [FeedController::class, 'get'])
    ->add($container->get(\Lewisdale\App\Session\LoginMiddleware::class));

$app->get('/feed/{id}', [FeedController::class, 'get_feed']);

$app->group('/account', function (\Slim\Routing\RouteCollectorProxy $group) use ($app, $container) {
   $group->get('/login', [LoginController::class, 'index']);
   $group->post('/login', [LoginController::class, 'login']);
});

$app->addErrorMiddleware(true, true, true);

$app->run();